Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CallstackOfColoredFunctions ¶
type CallstackOfColoredFunctions struct {
// Stack is functions placed in order, only colored functions.
Stack Nodes
// ColorsChain is blended colors of stacked functions, one-by-one.
ColorsChain []palette.Color
// IndexSet is quick index for contains(), has the same elements as stack.
IndexSet map[*Node]struct{}
// ColorsMask is mask of all colors_chain.
ColorsMask palette.ColorMask
}
func NewCallstackOfColoredFunctions ¶
func NewCallstackOfColoredFunctions() *CallstackOfColoredFunctions
func (*CallstackOfColoredFunctions) Append ¶
func (c *CallstackOfColoredFunctions) Append(fun *Node)
func (*CallstackOfColoredFunctions) AsVector ¶
func (c *CallstackOfColoredFunctions) AsVector() Nodes
func (*CallstackOfColoredFunctions) Contains ¶
func (c *CallstackOfColoredFunctions) Contains(fun *Node) bool
func (*CallstackOfColoredFunctions) PopBack ¶
func (c *CallstackOfColoredFunctions) PopBack()
func (*CallstackOfColoredFunctions) Size ¶
func (c *CallstackOfColoredFunctions) Size() int
type Node ¶
type Node struct {
Function *symbols.Function
// Next is an array of functions that are called from the current one.
// Prev is an array of functions that call the current one.
//
// All functions are always contained here, in contrast to Graph,
// where some functions can be deleted.
// Use these fields only if you need to know if there is a connection,
// but for other, use the Graph.
Next Nodes
Prev Nodes
// Pointer to a slice containing the
// following nodes that have colors.
NextWithColors *Nodes
}
Click to show internal directories.
Click to hide internal directories.